<?php

	/*
	 * To change this license header, choose License Headers in Project Properties.
	 * To change this template file, choose Tools | Templates
	 * and open the template in the editor.
	 */

	/**
	 * Description of VotesController
	 *
	 * @author Luke
	 */
	class VotesController extends VebraAppController {

		public $components = array('Cookie');

		/**
		 * Add a positive vote for the given property
		 * @param int $propertyId
		 * @return boolean
		 */
		public function positive($propertyId) {
			return $this->_add($propertyId, true);
		}

		/**
		 * Add a negative vote for the given property
		 * @param int $propertyId
		 * @return boolean
		 */
		public function negative($propertyId, $reason) {
			return $this->_add($propertyId, false, $reason);
		}

		/**
		 * Add a vote for a property which is either positive or negative
		 * @param int $propertyId
		 * @param boolean $positive
		 * @return boolean
		 */
		protected function _add($propertyId, $positive = true, $negativeReason = null) {
			$this->Vote->create();
			$data = array(
				'property_id' => $propertyId,
				'positive' => ($positive ? true : false)
			);
			if ($positive === false && $negativeReason !== null) {
				$data['negative_reason'] = $negativeReason;
			}

			if ($this->Vote->save($data)) {
				$this->Cookie->write('Property.Vote.' . $propertyId, $data);
				if ($this->request->is('ajax', 'ajax')) {
					$this->render('Vebra.Common/ajax-default', 'ajax');
				} else {
					return true;
				}
			} else {
				if ($this->request->is('ajax', 'ajax')) {
					$this->render('Vebra.Common/ajax-default', 'ajax');
				} else {
					return false;
				}
			}
		}

		protected function _adminIndexColumns() {
			$data = parent::_adminIndexColumns();
			$columns = array(
				'Vote.positive' => array(
					'type' => 'boolean',
					'label' => 'Positive Vote'
				),
				'0.full_address' => array(
					'type' => 'untouched',
					'label' => 'Property'
				),
				'Vote.negative_reason' => array(
					'type' => 'string',
					'label' => 'Reason for Negative Vote'
				),
			);
			$adminColumns = ArrayUtil::addAfter($data, 'Vote.id', $columns);
			return $adminColumns;
		}

		protected function _adminIndexPaginate() {
			$data = parent::_adminIndexPaginate();
			$data['contain']['Property'] = array(
				'fields' => 'CONCAT_WS(", ", Property.name, Property.street, Property.locality, Property.town, Property.postcode) AS full_address'
			);
			return $data;
		}

		protected function _adminIndexActions() {
			return array();
		}

		protected function _adminIndexToolbar() {
			$toolbar = parent::_adminIndexToolbar();
			unset($toolbar['Add New']);
			return $toolbar;
		}

	}
